/**
 mfstream - maya file string (for lack of a better name)

  This is a simple class to wrap binary io for maya files. 
  Since this is an early release, I'm happy with it just
  reading the entire file into a big buffer. Later it would be
  nice to implement this class using a smaller and smarter
  buffering system.

  Copyright 2001 Colin Stolley
*/
  

#include <stdio.h>
#include <string.h>

#define OUTPUT_BUFFER_SIZE 1024

extern char* getFilename( char* path );

class mfstream {

public:
	char* getNextString(); // works like unix 'strings'
	long getFileSize();  // returns file size in bytes
	int getByte( char &byte );  // returns next byte in buffer
	int ungetByte( char byte );
	int writeByte( char byte ); // writes byte to buffered output stream
	int writeString( char* str);  // writes null-terminated string to buffered output stream
	int flushOutputBuffer(); // flush buffered output stream
	int fileCopy( char* source, char* dest );
	mfstream(char* file);  
	mfstream(char* input, char* output);  
	char* getOutputFileName() { return Output_file_name; };
	char* getInputFileName() { return Input_file_name; };

	bool ready() { return (InputValid && OutputValid); };

	~mfstream();

private: 

	//members

	FILE* Input_file_ptr; // ptr to buffered binary file
	char* Input_file_name; // name of input file
	FILE* Output_file_ptr; // ptr to buffered binary file
	char* Output_file_name; // name of output file

	unsigned char* Input_buffer; // ptr to file buffer
	long Input_buffer_size; // size of buffer (file size)
	int Input_buffer_pos; // position in buffer

	unsigned char* Output_buffer; // ptr to file output buffer
	long Output_buffer_size; // size of buffer
	int Output_buffer_pos; // position in buffer

	bool InputValid;
	bool OutputValid;


	// methods
	
	void openInputFile( char* file ); // init File_ptr
	void openOutputFile( char* file ); // init File_ptr
	void init( char* input, char* output );

	int loadBuffer(); // read data into buffer
};
